@@ -45,9 +45,9 @@
 #include <kcalutils/incidenceformatter.h>
 
 #include <klocalizedstring.h>
-#include <kdatetime.h>
 
-#include <QtCore/QBuffer>
+#include <QBuffer>
+#include <QTimeZone>
 
 #include <time.h>
 
@@ -73,8 +73,8 @@ static QString sNamedProp(KTNEFMessage *tnefMsg, const QString &name,
 }
 
 struct save_tz {
-    char *old_tz;
-    char *tz_env_str;
+    char *old_tz = nullptr;
+    char *tz_env_str = nullptr;
 };
 
 /* temporarily go to a different timezone */
@@ -92,7 +92,7 @@ static struct save_tz set_tz(const char *_tc)
     char *tz_env = nullptr;
     const QByteArray tzEnv = qgetenv("TZ");
     if (!tzEnv.isEmpty()) {
-        tz_env = qstrdup(tzEnv);
+        tz_env = qstrdup(tzEnv.constData());
         rv.old_tz = tz_env;
     }
     char *tmp_env = (char *)malloc(strlen(tc) + 4);
@@ -132,7 +132,7 @@ static void unset_tz(struct save_tz old_tz)
     }
 }
 
-static KDateTime utc2Local(const KDateTime &utcdt)
+static QDateTime utc2Local(const QDateTime &utcdt)
 {
     struct tm tmL;
 
@@ -141,11 +141,11 @@ static KDateTime utc2Local(const KDateTime &utcdt)
     unset_tz(tmp_tz);
 
     localtime_r(&utc, &tmL);
-    return KDateTime(QDate(tmL.tm_year + 1900, tmL.tm_mon + 1, tmL.tm_mday),
+    return QDateTime(QDate(tmL.tm_year + 1900, tmL.tm_mon + 1, tmL.tm_mday),
                      QTime(tmL.tm_hour, tmL.tm_min, tmL.tm_sec));
 }
 
-static KDateTime pureISOToLocalQDateTime(const QString &dtStr,
+static QDateTime pureISOToLocalQDateTime(const QString &dtStr,
         bool bDateOnly = false)
 {
     QDate tmpDate;
@@ -167,11 +167,11 @@ static KDateTime pureISOToLocalQDateTime(const QString &dtStr,
         minute = dtStr.midRef(11, 2).toInt();
         second = dtStr.midRef(13, 2).toInt();
     }
-    tmpDate.setYMD(year, month, day);
+    tmpDate.setDate(year, month, day);
     tmpTime.setHMS(hour, minute, second);
 
     if (tmpDate.isValid() && tmpTime.isValid()) {
-        KDateTime dT = KDateTime(tmpDate, tmpTime);
+        QDateTime dT = QDateTime(tmpDate, tmpTime);
 
         if (!bDateOnly) {
             // correct for GMT ( == Zulu time == UTC )
@@ -183,7 +183,7 @@ static KDateTime pureISOToLocalQDateTime(const QString &dtStr,
         }
         return dT;
     } else {
-        return KDateTime();
+        return QDateTime();
     }
 }
 //@endcond
@@ -195,7 +195,7 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
     KTNEFParser parser;
     QByteArray b(tnef);
     QBuffer buf(&b);
-    MemoryCalendar::Ptr cal(new MemoryCalendar(KDateTime::UTC));
+    MemoryCalendar::Ptr cal(new MemoryCalendar(QTimeZone::utc()));
     KContacts::Addressee addressee;
     ICalFormat calFormat;
     Event::Ptr event(new Event());
@@ -284,7 +284,7 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
                     for (auto it = attendees.cbegin(), end = attendees.cend(); it != end; ++it) {
                         // Skip all entries that have no '@' since these are
                         // no mail addresses
-                        if ((*it).indexOf(QLatin1Char('@')) == -1) {
+                        if (!(*it).contains(QLatin1Char('@'))) {
                             s = (*it).trimmed();
 
                             Attendee::Ptr attendee(new Attendee(s, s, true));
@@ -338,10 +338,10 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
                 }
 
                 s = tnefMsg->findProp(0x819b).remove(QLatin1Char('-')).remove(QLatin1Char(':'));
-                event->setDtStart(KDateTime::fromString(s));     // ## Format??
+                event->setDtStart(QDateTime::fromString(s));     // ## Format??
 
                 s = tnefMsg->findProp(0x819c).remove(QLatin1Char('-')).remove(QLatin1Char(':'));
-                event->setDtEnd(KDateTime::fromString(s));
+                event->setDtEnd(QDateTime::fromString(s));
 
                 s = tnefMsg->findProp(0x810d);
                 event->setLocation(s);
@@ -374,10 +374,10 @@ QString KTnef::msTNEFToVPart(const QByteArray &tnef)
                 // is reminder flag set ?
                 if (!tnefMsg->findProp(0x8503).isEmpty()) {
                     Alarm::Ptr alarm(new Alarm(event.data()));     // TODO: fix when KCalCore::Alarm is fixed
-                    KDateTime highNoonTime =
+                    QDateTime highNoonTime =
                         pureISOToLocalQDateTime(tnefMsg->findProp(0x8502).
                                                 remove(QLatin1Char('-')).remove(QLatin1Char(':')));
-                    KDateTime wakeMeUpTime =
+                    QDateTime wakeMeUpTime =
                         pureISOToLocalQDateTime(tnefMsg->findProp(0x8560, QString()).
                                                 remove(QLatin1Char('-')).remove(QLatin1Char(':')));
                     alarm->setTime(wakeMeUpTime);
