@@ -94,17 +94,17 @@ public:
     /**
      * Returns true if the #TitleParsed flag is set; else returns false.
      */
-    bool titleParsed() const;
+    Q_REQUIRED_RESULT bool titleParsed() const;
 
     /**
      * Returns true if the ParseState::DataParsed flag is set; else returns false.
      */
-    bool dataParsed() const;
+    Q_REQUIRED_RESULT bool dataParsed() const;
 
     /**
      * Returns true if the #InfoParsed flag is set; else returns false.
      */
-    bool infoParsed() const;
+    Q_REQUIRED_RESULT bool infoParsed() const;
 
     /**
      * Sets/Unsets the attachment state according to the @p state flag
@@ -113,7 +113,7 @@ public:
      * @param state a #ParseState type.
      * @return true if the state is turned-on; else returns false.
      */
-    bool checkState(int state) const;
+    Q_REQUIRED_RESULT bool checkState(int state) const;
 
     /**
      * Sets the offset value of this attachment to @p offset.
@@ -125,7 +125,7 @@ public:
     /**
      * Returns the offset value of the attachment.
      */
-    int offset() const;
+    Q_REQUIRED_RESULT int offset() const;
 
     /**
      * Sets the size of the attachment to @p size.
@@ -137,7 +137,7 @@ public:
     /**
      * Returns the size of the attachment.
      */
-    int size() const;
+    Q_REQUIRED_RESULT int size() const;
 
     /**
      * Sets the display size of the attachment to @p size.
@@ -149,7 +149,7 @@ public:
     /**
      * Returns the display size of the attachment.
      */
-    int displaySize() const;
+    Q_REQUIRED_RESULT int displaySize() const;
 
     /**
      * Sets the name of this attachment to @p str.
@@ -161,7 +161,7 @@ public:
     /**
      * Returns the name of the attachment.
      */
-    QString name() const;
+    Q_REQUIRED_RESULT QString name() const;
 
     /**
      * Sets the index of this attachment to @p indx.
@@ -173,7 +173,7 @@ public:
     /**
      * Returns the index of the attachment.
      */
-    int index() const;
+    Q_REQUIRED_RESULT int index() const;
 
     /**
      * Sets the filename of this attachment to @p str.
@@ -185,7 +185,7 @@ public:
     /**
      * Returns the filename of the attachment.
      */
-    QString fileName() const;
+    Q_REQUIRED_RESULT QString fileName() const;
 
     /**
      * Sets the display name of this attachment to @p str.
@@ -197,7 +197,7 @@ public:
     /**
      * Returns the display name of the attachment.
      */
-    QString displayName() const;
+    Q_REQUIRED_RESULT QString displayName() const;
 
     /**
      * Sets the @acronym MIME tag of this attachment to @p str.
@@ -209,7 +209,7 @@ public:
     /**
      * Returns the @acronym MIME tag of the attachment.
      */
-    QString mimeTag() const;
+    Q_REQUIRED_RESULT QString mimeTag() const;
 
     /**
      * Sets the filename extension of this attachment to @p str.
@@ -221,7 +221,7 @@ public:
     /**
      * Returns the filename extension of the attachment.
      */
-    QString extension() const;
+    Q_REQUIRED_RESULT QString extension() const;
 
 private:
     //@cond PRIVATE
